.labels_add: Label regions of interest
Description
Add labels to regions of interest in an image
Usage
.labels_add(px, tolerance, n)
Arguments
tolerance
A numeric to be passed to label
n
A numeric, the number of desired regions of interest
Value
An object of class cimg. The labels are coded
the values in the object starting from 1. The rest of the image is labeled 0.